@@ -1,3 +1,4 @@
+#2 "utils/config.mlp"
 (**************************************************************************)
 (*                                                                        *)
 (*                                 OCaml                                  *)
@@ -67,9 +68,10 @@ let mkdll, mkexe, mkmaindll =
     "gcc -shared", "gcc", "gcc -shared"
 
 let flambda = false
+let safe_string = false
 
 let exec_magic_number = "Caml1999X011"
-and cmi_magic_number = "Caml1999I020"
+and cmi_magic_number = "Caml1999I021"
 and cmo_magic_number = "Caml1999O011"
 and cma_magic_number = "Caml1999A012"
 and cmx_magic_number =
@@ -82,10 +84,10 @@ and cmxa_magic_number =
     "Caml1999Z015"
   else
     "Caml1999Z014"
-and ast_impl_magic_number = "Caml1999M019"
+and ast_impl_magic_number = "Caml1999M020"
 and ast_intf_magic_number = "Caml1999N018"
 and cmxs_magic_number = "Caml2007D002"
-and cmt_magic_number = "Caml2012T007"
+and cmt_magic_number = "Caml2012T008"
 
 let load_path = ref ([] : string list)
 
@@ -108,6 +110,10 @@ let system = "linux"
 let asm = "as"
 let asm_cfi_supported = true
 let with_frame_pointers = false
+let spacetime = false
+let libunwind_available = false
+let libunwind_link_flags = ""
+let profinfo_width = 26
 
 let ext_obj = ".o"
 let ext_asm = ".s"
@@ -156,6 +162,8 @@ let print_config oc =
   p "host" host;
   p "target" target;
   p_bool "flambda" flambda;
+  p_bool "spacetime" spacetime;
+  p_bool "safe_string" safe_string;
 
   (* print the magic number *)
   p "exec_magic_number" exec_magic_number;
